pub fn order<I: Index>(
perm: &mut [I],
perm_inv: &mut [I],
A: SymbolicSparseColMatRef<'_, I>,
control: Control,
stack: &mut MemStack,
) -> Result<(), FaerError>Expand description
computes the approximate minimum degree ordering for reducing the fill-in during the sparse qr factorization of a matrix with the sparsity pattern of $A$
note
allows unsorted matrices